/* ASCEND Summer Workshop 2020
 *  This is a reference sketch to be used with the
 *  Control Systems Part 1 workshop material.
 *  
 *  Included in this sketch:
 *  - Creating variables
 *  - Basic arithmetic
 *  - Fractions and formatting
 *   
 *  Note: Open the serial monitor to view output. 
 *        Hit the reset button to watch the loop
 *        start from the beginning!
 */

void setup() {
  // Begin serial connection.
  // This is a requirement to print to the
  // serial monitor. Use 9600 for now.
  Serial.begin(9600);
}

void loop() {
  // Begin loop, follow the serial monitor!
  Serial.println("--Beginning of loop--");

  delay(2000);    // Delay will wait time in milliseconds 
  
  // Declaring variables
  // Data types are only included upon creation  
  int x = 5;       // x is now 5
  int y = 3;       // y is now 3
  float z = 16.5;  // z is now 16.5
  boolean state = true; // state is now true

  // Creates 4 variables that equal 0
  int sum1 = 0, sum2 = 0, prod = 0, mod = 0;

  // Operations
  sum1 = x + y;   // sum1 is now 8
  sum2 = x - y;   // sum2 is now 2
  prod = x * y;   // prod is now 15
  mod = 21 % 5;   // mod is now 1 (remainder)
  ++sum1;         // increases sum1 by 1
  --sum1;         // decreases sum1 by 1
  z += 5;         // increases z by 5
  z /= 2;         // divides z by 2

  // Printing with formatting. Notice print and println used in
  // combination to achieve desired appearance
  Serial.print("sum1: "); Serial.println(sum1);   // Note: Do not concatenate
  Serial.print("sum2: "); Serial.println(sum2);   // text/vars inside prints  
  Serial.print("prod: "); Serial.println(prod);   // Uses too much memory
  Serial.print("mod: "); Serial.println(mod);

  delay(2000);    // wait two seconds

  // Working with fractions
  // Use the proper data types!
  float a = 5;
  float b = 3;
  float quo = 0;

  // If assigning the result of dividing two integers,
  // the float would not retain the numbers after the 
  // decimal point! Example:
  //  float quo = x / y;
  // Since x and y are integers, they will not save the
  // fractional part. You can resolve this in two ways:
  
  // 1. Using number directly, you can include
  // the decimal points to make the result work
  // float quo = 5.0 / 3.0;
  // This format retains the fractional part.

  // 2. Make sure at least one of your data types is a 
  // float or double when dividing.
  // double x = 5; <--- having at least one double/float
  // int y = 3;
  // float quo = x / y; <--- will make this work

        

  quo = a / b;    // quo is now 1.666667

  // Printing normally
  Serial.print("quo: ");    // By default, only prints 2
  Serial.println(quo);      // significant digits, rounded

  // Printing quo with 4 digits
  Serial.print("quo with digits: ");
  Serial.println(quo, 4);

  delay(2000);    // wait two seconds

  // Operator precedence 
  float prec = 0;
  prec = (10 * 4) / 2 - 5;  // should be 15.00

  // print the result
  Serial.print("prec: "); Serial.println(prec);

  delay(2000);    // wait two second

  // End of loop, will go right back to beginning
  Serial.println("-----End of loop-----");
}
