/*ASCEND Summer Workshop 2020
 * Potentiometer with LED Activity
 * 
 * This is a reference sketch to be used with the 
 * Control Systems Part 1 workshop material.
 * 
 * This sketch includes
 * - basic if statements
 * - if/else and if/else if
 * - AND, OR, NOT operators
 * - Using comparison operators
 */
 
void setup() {
  // Begin serial connection
  Serial.begin(9600);
}

void loop() {

  // Declaring variables
  int x = 5;
  int y = 2;
  int z = 5;

  // mark loop start
  Serial.println("---Begin loop---");

  // All conditions go are in parenthesis after the
  // logic type. When the condition is met, the next
  // block within curly braces will be triggered

  // if statement example
  Serial.println("---Using if---");
  if (x > y) {
    // if condition is true, print this statement
    Serial.println("if statement triggered: x is greater than y.");
  }

  delay(5000);

  // When multiple conditions are available to be checked,
  // the block that is true will trigger and adjacent conditions
  // will be skipped.

  // if/else example
  Serial.println("---Using if/else---");
  if (x < y) {
    // if condition is true, print this statement
    Serial.println("if block triggered: x is less than y.");
  } else {
    // if condition is not true, print this statement
    Serial.println("else block triggered: x is not less than y.");
  }

  delay(5000);

  // if/else if lets you check multiple possibilities

  // if/else if example
  Serial.println("---Using if/else if---");
  if (x > z) {
    Serial.println("if block triggered: x is greater than z.");
  } else if (x < z) {
    Serial.println("else if block triggered: x is less than z.");
  } else {
    // through process of elimination, this else block implies
    // the only remaining possibility is that x equals z
    Serial.println("else block triggered: x equals z.");
  }

  delay(5000);

  // If two of your conditions can be considered
  // true, only the first one will be triggered.

  // multiple truths example
  Serial.println("---Testing two true conditions---");
  if (x >= y) {
    // since this block comes first, it will trigger
    Serial.println("if block triggered: x is greater than y.");
  } else if (x == 5) {
    // this block will not trigger even though it is true
    Serial.println("else if block triggered: x equals 5");
  }

  delay(5000);

  // Using booleans you can check if something is true or false
  // by its assigned value. This can be done a few different ways.

  // example of checking boolean state directly
  boolean testBool = false;
  Serial.println("---Checking boolean state---");
  if (testBool == true) {
    Serial.println("== condition: testBool is true");
  } else {
    Serial.println("else block triggered: testBool is false");
  }

  delay(5000);

  // not equals example
  Serial.println("---Using != operator---");
  if (testBool != true) {
    Serial.println("!= condition: testBool is false.");
  }

  delay(5000);

  // AND, OR, NOT examples
  Serial.println("--- Using AND, OR, and NOT---");
  
  // AND operator requires all conditions separated by && to be true
  // to trigger the block
  if (x == 5 && y == 2) {
    Serial.println("AND: x equals 5 and y equals 2 are true.");
  }

  // OR operator needs at least one condition separated by || to be
  // true to trigger the block
  if (z == 222222 || x != 52 || x >= 2) {
    Serial.println("OR: one of the conditions is true.");
  }

  // ! operator inverts condition, checks if something
  // is not true. Same as != with booleans.
  if (!testBool) {   // checks if testBool is not true
    Serial.println("!testBool triggered: testBool is not true (false)");
  } else {          // only other possibility is true
    Serial.println("!testBool triggered: testBool is true");
  }

  Serial.println("---End Loop---");
  delay(5000);
  

}
